#!/bin/bash -x

FRESH=-1;
REGISTER=0;
DIR=$(dirname $0)
LSCTL="/etc/init.d/landscape-client"
STATUS=0;
CACERT=/etc/ssl/certs/landscape_server_ca.crt

CLIENT=""
SERVER=""
PASSWORD=""


die() {
    STATUS=$?
    echo "ERROR: $1"
    exit $STATUS 
}

error() {
    STATUS=$?
    echo "ERROR: $1"
}

show_help() {
    cat <<EOF
Usage: $0 { --update } CLIENT
       $0 { --register | --fresh } CLIENT SERVER PASSWORD
       $0 [--help]
EOF
}

apt_get() {
    DEBIAN_FRONTEND=noninteractive apt-get \
        -y -o Dpkg::Options::='--force-confold' $*;
}

install_client() {
    apt_get update;
    apt_get install landscape-client
}


register_client() {
    landscape-config \
        --silent \
        --log-level=debug \
        -a standalone \
        -t ${CLIENT} \
        -p ${PASSWORD} \
        -u https://${SERVER}/message-system \
        --ping-url http://${SERVER}/ping \
        -k ${CACERT}
}

get_options() {
    while true; do
        case "$1" in
          -h|--help|-\?) show_help; exit 0;;
          -u|--update) FRESH=0; break;;
          -u|--fresh) FRESH=1; REGISTER=1; break;;
          -r|--register) REGISTER=1; break;;
          --) shift; break;;
          -*) echo "invalid option: $1" 1>&2; show_help; exit 1;;
          *)  break;;
        esac
    done
    CLIENT=$2
    SERVER=$3
    PASSWORD=$4
    if [ $FRESH -eq -1 ]; then
        show_help
        exit 1
    fi
    if [ "$HOSTNAME" == "" ]; then
        show_help
        exit 1
    fi
}

## MAIN

get_options $@

if [ $FRESH -ne -1 ]; then
    install_client
fi

if [ $REGISTER -eq 1 ]; then
    register_client || error "Registration attempt failed."
    exit $STATUS
fi

$LSCTL restart || error "Client service did not restart cleanly."
sleep 2
$LSCTL status || error "Client service not running."

exit $STATUS
