#!/bin/bash -e

TMPFILE=$(mktemp) || exit 1
trap "rm -rf $TMPFILE" EXIT

API_VERSION="2008-02-01"
METADATA_URL="http://169.254.169.254/$API_VERSION/meta-data"
CA_CERT_FILE=/etc/ssl/certs/landscape_server_ca.crt
DIR="$( cd "$( dirname "$0" )" && pwd )"

. $DIR/cloud-create.sh


usage() {
    cat <<-EOF
USAGE: 
    $0 AMI CLIENT_PUBLIC_IP SERVER_PUBLIC_IP PASSWORD
    $0

AMI       = canonistack AMI to use (run without options to list available)
PUBLIC_IP = public ip to associate
SERVER_PUBLIC_IP = public IP of server to register this client with
PASSWORD = password to use when registering the client (from landsacpe GUI)

This script facilitates launching a cloud client.  It makes use of the 
client-deploy script to get things running after launching.  It will also
take care of retrieving the cert from the SERVER and copying it to the client,
etc.

This script will update an exsting server if it exists and is "pingable",
it will create an instnace if not.
EOF
}

if [ "$1" == "" ]; then
    usage
    echo
    echo "Please pass in an image or ubuntu series name to use:"
    get_images
    exit 1;
fi

if [ "$2" == "" ] || [ "$3" == "" ] || [ "$4" == "" ]; then
    usage
    exit 1
fi

AMI=$1
PUBLIC_IP=$2
SERVER_PUBLIC_IP=$3
PASSWORD=$4
INIT=cloud-init-hash-bang

echo "* Get hostname from server"
FQDN_CURL="curl -s ${METADATA_URL}/public-hostname"
SERVER=$(ssh -nq root@$SERVER_PUBLIC_IP $FQDN_CURL)

if srexec /bin/true; then
    echo "* Existing client: $PUBLIC_IP, updating"
    bootstrap
    srexec "cd /tmp && ./client-deploy.sh --update $PUBLIC_IP $SERVER $PASSWORD"
else
    echo "* Creating client, will register to LDS @ $SERVER_PUBLIC_IP"
    create_instance $AMI $PUBLIC_IP
    bootstrap

    echo "* Copy certificate file from server to client"
    scp -q root@$SERVER_PUBLIC_IP:$CA_CERT_FILE $TMPFILE
    scp -q $TMPFILE root@$PUBLIC_IP:$CA_CERT_FILE
    srexec chmod +r $CA_CERT_FILE

    echo "* Executing client setup script on instance"
    srexec "cd /tmp && ./client-deploy.sh --fresh $PUBLIC_IP $SERVER $PASSWORD"
fi
