#!/bin/bash -ex

DIR="$( cd "$( dirname "$0" )" && pwd )"
. "$DIR/cloud-create.sh"

# Pass along to deploy script on remote system
LDS_REPOSITORY=${LDS_REPOSITORY:-}

usage() {
    cat <<-EOF
USAGE: 
    $0 AMI PUBLIC_IP [SCRIPT ..]
    $0

AMI       = canonistack AMI to use (run without options to list available)
PUBLIC_IP = public ip to associate
SCRIPT    = any number of "hack" scripts to run on the server as root

This script facilitates launching a cloud lds server.  It makes use of the 
deploy script to get things running after launching.

If the server is running (ssh "ping" test works), the existing server will
be "updated", instead of created fresh.

The hack scripts need to be as named as is and in the deployment directory.
They will be executed as the super user on the remote system after the
deployment is finished.

At the moment, this script is designed only to work on Canonistack.
EOF
}

if [ "$1" == "" ]; then
    usage
    echo
    echo "Please pass in an image or ubuntu series name to use:"
    get_images
    exit 1;
fi

AMI=$1
shift

if [ -z $1 ]; then
    echo "* Assuming instance will give public IP (amazon)"
else
    if echo $1 | egrep -e '^[0-9\.]*$'; then
        PUBLIC_IP=$1
        shift
    fi
fi

if srexec /bin/true; then
    echo "* Existing LDS server: $PUBLIC_IP, updating"
    bootstrap
    srexec "cd /tmp && PUBLIC=${PUBLIC_IP} ./deploy.sh --update"
else
    echo "* Creating LDS server: $AMI $PUBLIC_IP"
    create_instance $AMI $PUBLIC_IP
    bootstrap
    srexec "cd /tmp && PUBLIC=${PUBLIC_IP} LDS_REPOSITORY=${LDS_REPOSITORY} ./deploy.sh --fresh"

    # Take out setting of public_ip once canonistack is fixed /dpb/17/feb/2012
    echo "* Re-Gen cert with internal name as CN, restart services"
    srexec "cd /tmp && PUBLIC=${PUBLIC_IP} LDS_REPOSITORY=${LDS_REPOSITORY} ./deploy.sh --certificate"
    srexec "lsctl restart && service apache2 restart"

    echo "* Running any 'hack' scripts."
    for script in $@; do
        echo "    * Running: $script"
        srexec "cd /tmp && bash -xe /tmp/$script"
    done
fi


# In all cases, grab log files.
mkdir -p logs
scp -Cr \
    root@$PUBLIC_IP:/var/log/landscape \
    root@$PUBLIC_IP:/etc/landscape \
    logs
