#!/bin/bash -xe

JENKINS=0
DIR="$( cd "$( dirname "$0" )" && pwd )"
. "$DIR/cloud-create.sh"
REMOTE_ROOT=/var/jenkins

usage() {
    cat <<-EOF

USAGE: 
    $0 AMI
    $0 --jenkins AMI ARGS
    $0

--jenkins       Launch the jenkins agent and attach to stdout/stdin

  AMI           canonistack AMI to use (run without options to list available)
                You can also specify something like "lucid", and the script
                should do what you expect.
  
  ARGS          Extra arguments to pass to dev-env-deploy script

This script facilitates launching a cloud slave.  It needs cloud credentials
in the environment as well as an .ssh & .bazaar directory that it can copy over
to the created cloud instance.  This means, you should probably only run this on
a server that has been set up with "team" credentials (like a jenkins server),
as you probably don't want to blast *your* credentials all over the cloud. :)

EOF
}

if [ "$1" == "" ]; then
    usage

    echo
    echo "Please pass in images name or ubuntu series name to use:"
    get_images
    exit 1;
fi

AMI=$1

if [ "$1" == "--jenkins" ]; then
    trap "terminate_instance" EXIT
    JENKINS=1
    AMI=$2
    shift
fi
shift

echo "* Creating Slave instance"
create_instance $AMI
srexec mkdir -p $REMOTE_ROOT
bootstrap

# TODO: REMOVE THIS, just doing for now to get nodejs copied over there.
scp -C $DIR/nodejs_0.3.0-1chl1~lucid1_amd64.deb root@$IP:
scp -C $DIR/python-coverage_3.4-1ubuntu2_amd64.deb root@$IP:

echo "* Seeding Credentials to New Instance"
scp -rp $HOME/.ssh/id_rsa* $HOME/.ssh/known_hosts root@$IP:.ssh/
scp -rp $HOME/.ssh/id_rsa* $HOME/.ssh/known_hosts ubuntu@$IP:.ssh/
rexec mkdir -p .bazaar
scp -rp $HOME/.bazaar/* ubuntu@$IP:.bazaar/
scp -rp $HOME/.gnupg ubuntu@$IP:
srexec chmod -R go-rwx /root/.ssh /home/ubuntu/.gnupg /home/ubuntu/.gnupg
srexec chown -R ubuntu:ubuntu /home/ubuntu/.ssh /home/ubuntu/.gnupg /home/ubuntu/.bazaar

echo "* Checking out source on instance"
rexec 'mkdir -p src/canonical && cd src/canonical && bzr branch lp:~landscape/landscape/qa-scripts'

echo "* Checking out a github repo, sometimes the first try fails"
rexec 'git clone http://github.com/isaacs/npm.git; /bin/true'

echo "* copying over launchpad credentials"
rexec 'mkdir -p ~/.config/tarmac'
scp -C $HOME/launchpad_oauth ubuntu@$IP:/home/ubuntu/.config/tarmac/credentials

echo "* Executing dev env setup script on instance"
rexec 'cd src/canonical/qa-scripts/deployment && ./create-devenv-client.sh'

if [ $JENKINS -eq 1 ]; then
    echo "* Cleaning up apt cache"
    srexec 'apt-get clean'
    srexec chown -R ubuntu $REMOTE_ROOT /mnt/jenkins
    scp -C /var/run/jenkins/war/WEB-INF/slave.jar ubuntu@$IP:$REMOTE_ROOT || /bin/true
    scp -C /var/cache/jenkins/war/WEB-INF/slave.jar ubuntu@$IP:$REMOTE_ROOT || /bin/true
    exec ssh ubuntu@$IP "cd $REMOTE_ROOT && java -jar slave.jar"
fi
