#!/bin/bash -ex

SRC=${1:-$HOME/src/devenv}
BRANCH=lp:landscape
BRANCH_CLIENT=lp:landscape-client
TARMAC='lp:~landscape/tarmac/ls-trunk'
HOME_DIR=/home/ubuntu
LAUNCHPAD_USERNAME=landscape-builder
EMAIL=landscape-dev@lists.canonical.com

install_deps() {
    ./dev/landscape-ubuntu-deps client </dev/null
    ./dev/landscape-ubuntu-deps ci </dev/null
}

checkout_source() {
    echo "* Checking out source on instance"
    mkdir -p $SRC

    echo "* Checking out tarmac source & installing"
    cd $SRC && bzr branch $TARMAC  tarmac || /bin/true
    cd $SRC/tarmac && sudo python setup.py install 

    # Branch landscape (fresh each time)
    mkdir -p $SRC/landscape && cd $SRC/landscape
    [ -d trunk ] && rm -rf trunk
    bzr co --lightweight $BRANCH trunk

    cd $SRC
    mkdir -p $SRC/landscape-client && cd $SRC/landscape-client
    [ -d trunk ] && rm -rf trunk
    bzr co --lightweight $BRANCH_CLIENT trunk

    cd $SRC/landscape/trunk
}

create_lp_login() {
    cat <<-EOF > $HOME_DIR/.bazaar/bazaar.conf
[DEFAULT]
launchpad_username = $LAUNCHPAD_USERNAME
email = $EMAIL
EOF
    cat <<-EOF > $HOME_DIR/.bazaar/authentication.conf
[Launchpad]
host = .launchpad.net
scheme = ssh
user = $LAUNCHPAD_USERNAME
EOF
}

checkout_source
create_lp_login
$SRC/landscape/trunk/dev/landscape-setup-repos
install_deps

exit 0
