#!/bin/bash -x

# This script is meant to be run on the development system you want to setup
# as the user who will be developing Landscape.
# 
# If you want to run it from an unattended script, you will need to make
# sure the script can sudo without interaction.
# 
# Also, this script assumes you have a working ssh and bzr environment.
# Namely, something like
#
# - https://wiki.canonical.com/Landscape/DevelopmentEnvironment
# 
# Down to "Configure Bazaar" has been followed

STATUS=0;
CODENAME=$(cat /etc/lsb-release | grep CODENAME | sed 's/.*=//')

DEP=$HOME/dep
SOURCES_FILE=/etc/apt/sources.list.d/landscape-devel-team.list
SRC=${1:-$HOME/src/canonical}
BRANCH=lp:landscape

STORM_BRANCH=lp:storm

die() {
    STATUS=$?
    echo "ERROR: $1"
    exit $STATUS 
}

install_deps() {
    ./dev/landscape-ubuntu-deps both </dev/null &>/tmp/package-log
    status=$?
    echo "Package Install Log: ";
    cat /tmp/package-log
    return $status
}

# TODO: remove this when I get a real PPA
lucid_nodejs() {
    if [ $CODENAME != "lucid" ]; then
        return 0
    fi
    sudo dpkg -i /root/nodejs_0.3.0-1chl1~lucid1_amd64.deb
    sudo dpkg -i /root/python-coverage_3.4-1ubuntu2_amd64.deb
}

if [ $CODENAME != "lucid" ]; then
    ## Branch storm -- run up front since it adjusts tunables that need
    ## a pgtune pass to get correct kernel parameters for.
    mkdir -p $SRC/storm && cd $SRC/storm
    if [ -d trunk ]; then
        cd trunk && bzr pull || die "Can't update"
    else
        bzr branch $STORM_BRANCH trunk || die "Can't checkout source"
        cd trunk
    fi
    ./dev/ubuntu-deps
    make develop
    ./dev/db-setup
fi

# Branch landscape
mkdir -p $SRC/landscape && cd $SRC/landscape
if [ -d trunk ]; then
    cd trunk && bzr pull || die "Can't update"
else
    bzr branch $BRANCH trunk || die "Cant checkout source"
    cd trunk
fi

# setup the environment
./dev/landscape-setup-env || die "Cant setup environment"
. ~/.landscape-env

./dev/landscape-setup-repos || die "Error adding repositories"
./dev/landscape-setup-users


# Something is happening here to cause SSH to hang, basically some
# kind of process is getting forked into the background, so we need to do some
# tricks to make sure this script can be run over an ssh connection.
# rabbitmq is the culprit, just don't know how it's different from other
# daemon installs.
#
# If running manually, this is just: ./dev/landscape-ubuntu-deps both
#
install_deps || die "Can't install deps"

# TODO: remove when I get a working PPA for nodejs on lucid
lucid_nodejs || die "Couldn't update nodejs on lucid correctly"

# install deps
./dev/landscape-yeti-setup || die "Cant setup yeti"
./dev/landscape-rabbitmq-setup || die "Cant setup rabbitmq"
./dev/landscape-ubuntu-deps ci || die "Can't install ci deps"

# Configure postgres for faster access
./dev/landscape-sysctl kernel.shmmax=209715200
./dev/landscape-postgres-tune || die "Error tuning postrgres"

# Create the landscape DB roles and databases
./dev/landscape-postgres-setup || die "Can't setup user roles"
make createdb || die "Can't create the databases"

# Make sure the dev tools can be installed
make build
make build-devel

if [ $CODENAME != "lucid" ]; then
    # One finaly time run the db-setup for storm.  It fails the first time
    # since pg db tuning wasn't done yet.
    cd $SRC/storm/trunk && ./dev/db-setup
fi
