#!/usr/bin/python

from subprocess import check_output, check_call, call
import json

tolerance = 60 * 60 * 3
def juju_status():
    result = check_output(["juju", "status", "--format=json"])
    return json.loads(result)

def juju_ssh(machine, command):
    print "SSH: %s: %s" % (machine, command)
    output = check_output(["juju", "ssh", machine, command]).rstrip()
    print "SSHOUT: %s" % output
    return output

def juju_terminate_machine(machine):
    print "TERMINATE %s" % machine
    check_call(["juju", "terminate-machine", machine])

def juju_remove_unit(unit):
    print "REMOVE UNIT %s" % unit
    call(["juju", "resolved", unit])
    check_call(["juju", "remove-unit", unit])

def cleanup_dead_units():
    status = juju_status()
    machines = status['machines']
    services = status['services']

    # an instnace_id should never be pending, in my experience
    # this means either some resource constraint on c-stack
    # or an error on launch.  Either way, it's a DOA condition
    # in juju that it will most likely never recover from
    machines_to_terminate = []
    for machine in machines:
        print machines[machine]
        if machines[machine]['instance-id'] == "pending":
            machines_to_terminate.append(machine)

    units_to_terminate = []
    for service in services:
        for unit in services[service]['units']:
            unit_data = services[service]['units'][unit]
            if str(unit_data['agent-state']) == "error":
                units_to_terminate.append(unit)
            if str(unit_data['machine']) in machines_to_terminate:
                units_to_terminate.append(unit)

    for unit in units_to_terminate:
        juju_remove_unit(unit)

    for machine in machines_to_terminate:
        juju_terminate_machine(machine)

def check_for_jenkins_agent():
    status = juju_status()
    services = status['services']

    for service in services:
        if 'devenv' not in service:
            continue
        for unit in services[service]['units']:
            unit_data = services[service]['units'][unit]
            machine = str(unit_data['machine'])
            if unit_data['agent-state'] == 'started':
                uptime = juju_ssh(machine, "cat /proc/uptime")
                (seconds, idle) = uptime.split()
                if seconds > tolerance:
                    jenkins = juju_ssh(machine, "ps -ef |grep j[a]va | grep s[l]ave.jar; /bin/true")
                    if jenkins.find("slave.jar") == -1:
                        juju_remove_unit(unit)
                        juju_terminate_machine(machine)

def terminate_all_machines():
    """
    Attempt to terminate all machines.  Juju is smart enough to ignore any
    request to delete that is in use.
    """
    status = juju_status()
    machines = status['machines']
    for machine in machines:
        print "Attempting to terminate, ignore failure: %s" % machines[machine]
        try:
            juju_terminate_machine(machine)
        except Exception:
            pass

cleanup_dead_units()
check_for_jenkins_agent()
terminate_all_machines()
